package com.gic.store.service.outer.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.DateUtil;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.util.GlobalInfo;
import com.gic.commons.util.PageHelperUtils;
import com.gic.enterprise.dto.CustomStoreDTO;
import com.gic.enterprise.dto.EnterpriseDTO;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.response.EnterpriseServiceResponse;
import com.gic.enterprise.service.CustomStoreApiService;
import com.gic.enterprise.service.EnterpriseApiService;
import com.gic.redis.data.util.RedisUtil;
import com.gic.search.business.api.constant.enums.OperateEnum;
import com.gic.search.business.api.dto.DynamicDocDTO;
import com.gic.search.business.api.dto.DynamicSearchDTO;
import com.gic.search.business.api.dto.ESResponseQueryBatchDTO;
import com.gic.search.business.api.service.EsBusinessOperaApiService;
import com.gic.search.business.api.utils.QueryConditionAssemblyUtil;
import com.gic.store.constant.*;
import com.gic.store.dto.*;
import com.gic.store.entity.*;
import com.gic.store.service.*;
import com.gic.store.strategy.BulkUpdateStoreStrtegy;
import com.gic.store.strategy.impl.*;
import com.gic.store.utils.field.*;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.elasticsearch.common.geo.GeoUtils;
import org.redisson.api.RKeys;
import org.redisson.api.RedissonClient;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import java.util.concurrent.TimeUnit;
import java.util.stream.Collectors;

/**
 * @author zhiwj
 * @date 2019/6/27
 */
@Service("storeApiService")
@SuppressWarnings("unchecked")
public class StoreApiServiceImpl implements StoreApiService {
    private static final Logger logger = LogManager.getLogger(StoreApiServiceImpl.class);
    private static Map<Integer, BulkUpdateStoreStrtegy> storeStrtegyMap = new HashMap<>();
    @Value("${storeExpiredTime}")
    private Long storeExpiredTime;
    @Autowired
    private StoreService storeService;
    @Autowired
    private StoreBrandService storeBrandService;
    @Autowired
    private StorePhotoService storePhotoService;
    @Autowired
    private StoreBusinessTimeService storeBusinessTimeService;
    @Autowired
    private StoreExtendService storeExtendService;
    @Autowired
    private StoreStrategyApiService storeStrategyApiService;
    @Autowired
    private StoreGroupService storeGroupService;
    @Autowired
    private StoreGroupApiService storeGroupApiService;
    @Autowired
    private StoreStrategyService storeStrategyService;
    @Autowired
    private StoreFieldSelectService storeFieldSelectService;
    @Autowired
    private StoreRegionService storeRegionService;
    @Autowired
    private EsBusinessOperaApiService esBusinessOperaApiService;
    @Autowired
    private EnterpriseApiService enterpriseApiService;
    @Autowired
    private StoreLogService storeLogService;
    @Autowired
    private StoreDictApiService storeDictApiService;
    @Autowired
    private CustomStoreApiService customStoreApiService;
    @Autowired
    private StoreWidgetApiService storeWidgetApiService;

    static {
        storeStrtegyMap.put(1, new StoreStatusStrategyImpl());
        storeStrtegyMap.put(2, new StorePhoneStategyImpl());
        storeStrtegyMap.put(3, new StoreBusinessTimeStrategyImpl());
        storeStrtegyMap.put(4, new StorePhotoUpdateStrategyImpl());
        storeStrtegyMap.put(5, new StoreBrandUpdateStrategyImpl());
        storeStrtegyMap.put(6, new StorePhotoAddStrategyImpl());
        storeStrtegyMap.put(7, new StoreGroupStrategyImpl());
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ServiceResponse<Integer> saveOrUpdate(StoreDTO storeDTO) {
        logger.info("storeDTO:{}", JSON.toJSONString(storeDTO));
        boolean codeValid = storeService.validateStoreCodeIsExist(storeDTO.getEnterpriseId(), storeDTO.getRegionId(), storeDTO.getStoreCode(), storeDTO.getStoreId());
        if (codeValid) {
            return ServiceResponse.failure(ErrorCode.DATA_EXISTS.getCode(), "门店代码已经存在");
        }
        boolean nameValid = storeService.validateStoreNameIsExist(storeDTO.getEnterpriseId(), storeDTO.getRegionId(), storeDTO.getStoreName(), storeDTO.getStoreId());
        if (nameValid) {
            return ServiceResponse.failure(ErrorCode.DATA_EXISTS.getCode(), "门店名称已经存在");
        }
        TabStoreRegion region = storeRegionService.getById(storeDTO.getEnterpriseId(), storeDTO.getRegionId());
        if (region == null) {
            return ServiceResponse.failure(ErrorCode.NOTEXISTS.getCode(), "门店域不存在");
        }
        if (storeDTO.getStoreGroupId() != null) {
            Integer storeGroupId = storeDTO.getStoreGroupId();
            Boolean result = storeGroupApiService.isLeafNode(storeGroupId).getResult();
            if (!result) {
                return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "门店分组必须为叶子节点");
            }
        }
        // 校验是否完全填写
        Integer completeStatus = storeService.checkCompleteStatus(storeDTO);
        storeDTO.setCompleteStatus(completeStatus);
        // 分组策略
        String msg = getGroup(storeDTO);
        if (StringUtils.isNotBlank(msg)) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), msg);
        }
        // 校验填写的品牌是否存在
        String brandMsg = validBrandIsExist(storeDTO.getBrandIds());
        if (StringUtils.isNotBlank(brandMsg)) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), brandMsg);
        }
        // 启用策略
        getStatus(storeDTO);

        if (storeDTO.getStoreId() == null) {
            Integer id = storeService.save(storeDTO);
            storeDTO.setStoreId(id);
            // 记录门店日志
            saveAddLog(storeDTO);
        } else {
            ServiceResponse<StoreDTO> existStore = this.getStoreById(storeDTO.getEnterpriseId(), storeDTO.getStoreId());
            storeDTO.setStoreInfoId(existStore.getResult().getStoreInfoId());
            Integer update = storeService.update(storeDTO);
            if (update == 0) {
                return ServiceResponse.failure(ErrorCode.NOTEXISTS.getCode(), ErrorCode.NOTEXISTS.getMsg());
            }
            // 记录门店日志
            saveUpdateLog(existStore.getResult(), storeDTO);
        }
        // 自定义属性
        storeExtendService.saveOrUpdate(storeDTO.getEnterpriseId(), storeDTO.getStoreInfoId(), storeDTO.getStoreExtendList());
        // 门店图片
        List<Integer> delPhotos = null;
        if (StringUtils.isNotEmpty(storeDTO.getDelPhotos())) {
            List<String> photoIds = Arrays.asList(storeDTO.getDelPhotos().split(","));
            delPhotos = photoIds.stream().map(Integer::parseInt).collect(Collectors.toList());
        }
        storePhotoService.editStoreImage(storeDTO.getEnterpriseId(), storeDTO.getStoreInfoId(), storeDTO.getPhotoList(), delPhotos);
        // 营业时间
        List<Integer> delBusinessTimes = null;
        if (StringUtils.isNotEmpty(storeDTO.getDelBusinessTimes())) {
            List<String> delBusinessTimeIds = Arrays.asList(storeDTO.getDelBusinessTimes().split(","));
            delBusinessTimes = delBusinessTimeIds.stream().map(Integer::parseInt).collect(Collectors.toList());
        }
        storeBusinessTimeService.editStoreBusinessTime(storeDTO.getEnterpriseId(), storeDTO.getStoreInfoId(), storeDTO.getBusinessTimeList(), delBusinessTimes);

        // 更新缓存
        refreshCache(storeDTO.getEnterpriseId(), storeDTO.getStoreId());
        return ServiceResponse.success();
    }

    /**
     * 修改日志
     */
    private void saveUpdateLog(StoreDTO oldStore, StoreDTO newStore) {
        StoreLogDTO storeLogDTO = new StoreLogDTO();
        storeLogDTO.setEnterpriseId(newStore.getEnterpriseId());
        storeLogDTO.setStoreId(newStore.getStoreId());
        storeLogDTO.setReason(newStore.getReason());
        storeLogDTO.setLogType(StoreLogTypeEnum.INFO_UPDATE.getCode());
        storeLogDTO.setRemark(newStore.getRemark());
        storeLogDTO.setOperatorId(newStore.getOperatorId());
        storeLogDTO.setOperatorName(newStore.getOperatorName());

        StringBuilder sb = new StringBuilder();
        if (StringUtils.isNotBlank(newStore.getStoreName()) && !StringUtils.equals(newStore.getStoreName(), oldStore.getStoreName())) {
            sb.append("门店名称").append("【").append(oldStore.getStoreName()).append("】")
                    .append("变更为【").append(newStore.getStoreName()).append("】");
        }
        if (!CollectionUtils.isEqualCollection(oldStore.getPhotoList(), newStore.getPhotoList())) {
            sb.append("门店照片变更");
        }
        if (newStore.getStoreType() != null && !newStore.getStoreType().equals(oldStore.getStoreType())) {
            ServiceResponse<StoreDictDTO> oldStoreType = this.storeDictApiService.getStoreDict("storeType", oldStore.getStoreType().toString());
            ServiceResponse<StoreDictDTO> newStoreType = this.storeDictApiService.getStoreDict("storeType", newStore.getStoreType().toString());
            sb.append("门店类型").append("【").append(oldStoreType.getResult().getKey()).append("】")
                        .append("变更为【").append(newStoreType.getResult().getKey()).append("】");
        }
        if (newStore.getErpStatus() != null && !newStore.getErpStatus().equals(oldStore.getErpStatus())) {
            ServiceResponse<StoreDictDTO> oldStoreStatus = this.storeDictApiService.getStoreDict("storeStatus", oldStore.getErpStatus().toString());
            ServiceResponse<StoreDictDTO> newStoreStatus = this.storeDictApiService.getStoreDict("storeStatus", newStore.getErpStatus().toString());
            sb.append("门店状态").append("【").append(oldStoreStatus.getResult().getKey()).append("】")
                        .append("变更为【").append(newStoreStatus.getResult().getKey()).append("】");
        }
        if (StringUtils.isNotBlank(newStore.getConactsPhone()) && !StringUtils.equals(newStore.getConactsPhone(), oldStore.getConactsPhone())) {
            sb.append("门店电话").append("【").append(oldStore.getConactsPhone()).append("】")
                    .append("变更为【").append(newStore.getConactsPhone()).append("】");
        }
        if (CollectionUtils.isNotEmpty(newStore.getBusinessTimeList())) {
            if (CollectionUtils.isEmpty(oldStore.getBusinessTimeList()) || !CollectionUtils.isEqualCollection(oldStore.getBusinessTimeList(), newStore.getBusinessTimeList())) {
                if (StringUtils.isNotBlank(newStore.getBusinessTimeList().get(0).getWeekday())) {
                    this.storeBusinessTimeService.convertBusinessTime(newStore.getBusinessTimeList());
                    String newBusinessTimeShow = newStore.getBusinessTimeList().stream()
                            .map(e -> e.getWeekdayShow() + ":" + DateUtil.dateToStr(e.getOpenTime(), DateUtil.FORMAT_MINUTE_TIME) + "~" + DateUtil.dateToStr(e.getCloseTime(), DateUtil.FORMAT_MINUTE_TIME))
                            .reduce((x, y) -> x + "," + y)
                            .orElse("");
                    sb.append("营业时间").append("变更为【").append(newBusinessTimeShow).append("】");
                }
            }
        }
        if (StringUtils.isNotBlank(newStore.getBrandIds()) && !StringUtils.equals(newStore.getBrandIds(), oldStore.getBrandIds())) {
            List<TabStoreBrand> tabStoreBrands = this.storeBrandService.listStoreBrandByIds(newStore.getBrandIds());
            String storeBrandShow = tabStoreBrands.stream().map(TabStoreBrand::getStoreBrandName).reduce((x, y) -> x + "," + y).orElse("");
            sb.append("门店品牌").append("变更为【").append(storeBrandShow).append("】");
        }
        if (StringUtils.isNotBlank(newStore.getAddress()) && !StringUtils.equals(newStore.getAddress(), oldStore.getAddress())) {
            sb.append("门店地址").append("【").append(oldStore.getAddress()).append("】")
                    .append("变更为【").append(newStore.getAddress()).append("】");
        }
        if (StringUtils.isNotBlank(newStore.getLongitude()) && !StringUtils.equals(newStore.getLongitude(), oldStore.getLongitude())) {
            if (StringUtils.isNotBlank(newStore.getLatitude()) && !StringUtils.equals(newStore.getLatitude(), oldStore.getLatitude())) {
                sb.append("门店经纬度").append("【").append(oldStore.getLongitude()).append(",").append(oldStore.getLatitude()).append("】")
                        .append("变更为【").append(newStore.getLongitude()).append(",").append(newStore.getLatitude()).append("】");
            }
        }
        if (!CollectionUtils.isEqualCollection(oldStore.getStoreExtendList(), newStore.getStoreExtendList())) {
            for (int i = 0; i < newStore.getStoreExtendList().size(); i++) {
                StoreExtendDTO newStoreExtend = newStore.getStoreExtendList().get(i);
                if (StringUtils.isNotBlank(newStoreExtend.getValue())) {
                    Integer fieldType = newStoreExtend.getStoreFieldType();
                    if (StoreFieldTypeEnum.RADIO.getCode() == fieldType || StoreFieldTypeEnum.CHECK.getCode() == fieldType) {
                        if (StringUtils.isNotBlank(newStoreExtend.getValue())) {
                            TabStoreFieldSelect select = storeFieldSelectService.getStoreFieldSelectById(Integer.parseInt(newStoreExtend.getValue()));
                            sb.append(newStoreExtend.getStoreFieldName()).append("变更为【").append(select.getStoreFieldSelectName()).append("】");
                        }
                    } else {
                        sb.append(newStoreExtend.getStoreFieldName()).append("变更为【").append(newStoreExtend.getValue()).append("】");
                    }
                }
            }
        }
        storeLogDTO.setContent(sb.toString());
        if (StringUtils.isNotBlank(storeLogDTO.getContent().trim())) {
            this.storeLogService.saveStoreLog(storeLogDTO);
        }
        // 分组
        if (newStore.getStoreGroupId() != null && !newStore.getStoreGroupId().equals(oldStore.getStoreGroupId())) {
            storeLogDTO.setLogType(StoreLogTypeEnum.GROUP_UPDATE.getCode());
            TabStoreGroup storeGroup = this.storeGroupService.getStoreGroupById(newStore.getStoreGroupId());
            storeLogDTO.setContent("门店分组变更为【" + storeGroup.getStoreGroupName() + "】");
            this.storeLogService.saveStoreLog(storeLogDTO);
        }
        // 状态
        if (newStore.getStatus() != null && !newStore.getStatus().equals(oldStore.getStatus())) {
            storeLogDTO.setLogType(StoreLogTypeEnum.STATUS_UPDATE.getCode());
            storeLogDTO.setContent("门店启用状态变更为【" + StoreStatusEnum.parseCode(newStore.getStatus()) + "】");
            this.storeLogService.saveStoreLog(storeLogDTO);
        }


    }

    /**
     * 新增日志
     */
    private void saveAddLog(StoreDTO storeDTO) {
        StoreLogDTO storeLogDTO = new StoreLogDTO();
        storeLogDTO.setEnterpriseId(storeDTO.getEnterpriseId());
        storeLogDTO.setStoreId(storeDTO.getStoreId());
        storeLogDTO.setContent("门店新增");
        storeLogDTO.setReason(storeDTO.getReason());
        storeLogDTO.setLogType(StoreLogTypeEnum.SAVE.getCode());
        storeLogDTO.setRemark(storeDTO.getRemark());
        storeLogDTO.setOperatorId(storeDTO.getOperatorId());
        storeLogDTO.setOperatorName(storeDTO.getOperatorName());

        this.storeLogService.saveStoreLog(storeLogDTO);
    }

    private String validBrandIsExist(String brandIds) {
        if (StringUtils.isBlank(brandIds)) {
            return null;
        }
        List<TabStoreBrand> storeBrandList = storeBrandService.listStoreBrandByIds(brandIds);
        if (CollectionUtils.isEmpty(storeBrandList) || brandIds.split(GlobalInfo.FLAG_COMMA).length > storeBrandList.size()) {
            return "品牌不存在";
        }

        return null;
    }

    private void refreshCache(Integer enterpriseId, Integer storeId) {
        String key = Constants.STORE_KEY + enterpriseId + ":" + storeId;
        RedisUtil.delCache(key);
    }

    private void refreshIndex(Integer storeId, Integer enterpriseId) {
        this.addStoreToIndex(enterpriseId, storeId);
    }

    /**
     * 根据策略判断启用状态
     * @param storeDTO
     */
    private void getStatus(StoreDTO storeDTO) {
        if (storeDTO.getStatus() == null) {
            String hitStrategy = storeStrategyService.isHitStrategy(storeDTO, StoreGroupConstant.STORE_STRATEGY_TYPE);
            storeDTO.setStatus(StringUtils.isNotBlank(hitStrategy) ? Integer.valueOf(hitStrategy) : StoreEnableOrDisAbleEnum.DISABLE.getCode());
        }
    }

    /**
     * 根据策略判断分组
     * @param storeDTO
     * @return
     */
    private String getGroup(StoreDTO storeDTO) {
        if (storeDTO.getIsEditStoreGroup() == 1 || Integer.valueOf(0).equals(storeStrategyApiService.getStoreGroupStrategyWeight(storeDTO.getEnterpriseId()).getResult())) {
            // 不启用分组策略
            if (storeDTO.getStoreGroupId() == null) {
                // 取 未分类 分组
                TabStoreGroup group = storeGroupService.selectUnGroupedStore(storeDTO.getEnterpriseId());
                storeDTO.setStoreGroupId(group.getStoreGroupId());
            } else {
                // 判断分组是否存在
                TabStoreGroup group = storeGroupService.getStoreGroupById(storeDTO.getStoreGroupId());
                if (group != null) {
                    storeDTO.setStoreGroupId(group.getStoreGroupId());
                } else {
                    logger.info("enterpriseId:{}, groupName:{}, 不存在该分组", storeDTO.getEnterpriseId(), storeDTO.getStoreGroupName());
                    return "门店分组不存在";
                }
            }
        } else {
            // 启用分组策略
            String groupId = storeStrategyService.isHitStrategy(storeDTO, StoreGroupConstant.STORE_GROUP_STRATEGY_TYPE);
            if (StringUtils.isNotBlank(groupId)) {
                // 命中
                storeDTO.setStoreGroupId(Integer.valueOf(groupId));
            } else {
                // 未命中
                TabStoreGroup group = storeGroupService.selectUnGroupedStore(storeDTO.getEnterpriseId());
                storeDTO.setStoreGroupId(group.getStoreGroupId());
            }
        }
        return null;
    }

    @Override
    public ServiceResponse<Page<StoreDTO>> listStore(StoreSearchDTO storeSearchDTO, Integer pageNum, Integer pageSize, String returnFileds) {
        if (storeSearchDTO.getEnterpriseId() == null) {
            return EnterpriseServiceResponse.failure(ErrorCode.ENTERPRISE_EMPTY);
        }
        JSONObject enterpriseJson = this.buildSearchJSON(storeSearchDTO);
        JSONObject sortJson = null;
        if(StringUtils.isNotBlank(storeSearchDTO.getLatitude()) && StringUtils.isNotBlank(storeSearchDTO.getLatitude())){
            sortJson = QueryConditionAssemblyUtil.createSortNodeByLocation(StoreESFieldsEnum.LOCATION.getField(), QueryConditionAssemblyUtil.SORT_RULE_ASC,
                    Double.valueOf(storeSearchDTO.getLatitude()), Double.valueOf(storeSearchDTO.getLongitude()));
        }else {
            sortJson = QueryConditionAssemblyUtil.createSortNode(StoreESFieldsEnum.STORECODE.getField(), QueryConditionAssemblyUtil.SORT_RULE_ASC);
        }
        ServiceResponse<ESResponseQueryBatchDTO> response = this.queryStoreFromES(enterpriseJson, pageNum, pageSize, sortJson, returnFileds);
        if (response.isSuccess()) {
            Page<StoreDTO> page = new Page(pageNum, pageSize);
            page.setTotalCount(Integer.valueOf(response.getResult().getTotalNumber() + ""));
            List<JSONObject> list = response.getResult().getRes();
            List<StoreDTO> result = new ArrayList<>();
            for(int i=0; i<list.size(); i++){
                StoreDTO storeDTO = JSON.toJavaObject(list.get(i), StoreDTO.class);
                if(StringUtils.isNotBlank(storeSearchDTO.getLatitude()) && StringUtils.isNotBlank(storeSearchDTO.getLongitude()) &&
                        CollectionUtils.isNotEmpty(storeDTO.getLocation())){
                    double v = GeoUtils.arcDistance(Double.valueOf(storeSearchDTO.getLatitude()), Double.valueOf(storeSearchDTO.getLongitude()),
                            Double.valueOf(storeDTO.getLocation().get(1)), storeDTO.getLocation().get(0));
                    storeDTO.setDistance(v);
                }
                result.add(storeDTO);
            }
            page.setResult(result);
            return ServiceResponse.success(page);
        }
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<Page<StoreDTO>> listStore(StoreSearchDTO storeSearchDTO, Integer pageNum, Integer pageSize){
        StoreESFieldsEnum[] values = StoreESFieldsEnum.values();
        StringBuilder returnFileds = new StringBuilder();
        for(int i=0; i< values.length; i++){
            if(i == values.length-1){
                returnFileds.append(values[i].getField());
            }else {
                returnFileds.append(values[i].getField()).append(",");
            }
        }
        return this.listStore(storeSearchDTO, pageNum, pageSize, returnFileds.toString());
    }

    @Override
    public ServiceResponse queryStoreFromES(JSONObject jsonObject, Integer pageNum, Integer pageSize, JSONObject sortJson, String returnFileds) {
        if (StringUtils.isBlank(returnFileds)) {
            returnFileds = StoreESFieldsEnum.STOREID.getField();
        }
        DynamicSearchDTO dynamicSearchDTO = new DynamicSearchDTO();
        dynamicSearchDTO.setSearchJson(jsonObject);
        dynamicSearchDTO.setEnterpriseId(com.gic.enterprise.constants.Constants.INDEX_ENTERPRISEID);
        dynamicSearchDTO.setColumnCategoryCode(com.gic.enterprise.constants.Constants.ColumnCategoryCode);
        dynamicSearchDTO.setBegin((pageNum - 1) * pageSize);
        dynamicSearchDTO.setRecordNumber(pageSize > 10000 ? 10000 : pageSize);
        dynamicSearchDTO.setSortJson(sortJson);
        dynamicSearchDTO.setReturnFileds(returnFileds);
        logger.info("es查询条件：{}", JSON.toJSONString(dynamicSearchDTO,true));
        ServiceResponse<ESResponseQueryBatchDTO> response = this.esBusinessOperaApiService.queryDataBatch(dynamicSearchDTO, false, null);
        logger.info("es查询结果：,{}", JSON.toJSONString(response, true));
        return response;
    }

    @Override
    public ServiceResponse<Long> queryStoreCountFromES(StoreSearchDTO storeSearchDTO){
        JSONObject json = this.buildSearchJSON(storeSearchDTO);
        logger.info("es查询门店数量json：{}", json.toJSONString());
        DynamicSearchDTO dynamicSearchDTO = new DynamicSearchDTO();
        dynamicSearchDTO.setSearchJson(json);
        dynamicSearchDTO.setEnterpriseId(com.gic.enterprise.constants.Constants.INDEX_ENTERPRISEID);
        dynamicSearchDTO.setColumnCategoryCode(com.gic.enterprise.constants.Constants.ColumnCategoryCode);
        ServiceResponse<Long> response = this.esBusinessOperaApiService.queryDataCount(dynamicSearchDTO);
        if(response.isSuccess()){
            return response;
        }
        return ServiceResponse.success(0l);
    }

    @Override
    public ServiceResponse<Void> deleteStoreFromES(Integer enterpriseId, Integer storeId) {
        JSONObject json = new JSONObject();
        json.put(StoreESFieldsEnum.ID.getField(), enterpriseId+"_"+storeId);
        DynamicSearchDTO dynamicSearchDTO = new DynamicSearchDTO();
        dynamicSearchDTO.setSearchJson(json);
        dynamicSearchDTO.setEnterpriseId(com.gic.enterprise.constants.Constants.INDEX_ENTERPRISEID);
        dynamicSearchDTO.setColumnCategoryCode(com.gic.enterprise.constants.Constants.ColumnCategoryCode);
        return this.esBusinessOperaApiService.deleteDataSingle(dynamicSearchDTO);
    }

    @Override
    public ServiceResponse<JSONObject> parseStoreSelectJson(String searchJson) {
        JSONArray array = JSON.parseArray(searchJson);
        JSONObject result = null;
        for(int i=0; i< array.size(); i++){
            JSONObject jsonObject = array.getJSONObject(i);
            String type = jsonObject.getString("type");
            JSONArray list = jsonObject.getJSONArray("list");
            List<JSONObject> jsonObjectList = new ArrayList<>();
            for(int j =0 ;j< list.size(); j++){
                list.getJSONObject(j).put("type", "data");
                jsonObjectList.add(list.getJSONObject(j));
            }
            JSONObject json = null;
            if(i > 0 && OperateEnum.OPERATE_AND_NOT.getValue().equals(type)){
                json = QueryConditionAssemblyUtil.createListQueryNode(jsonObjectList, OperateEnum.OPERATE_AND_NOT);
            }else {
                json = QueryConditionAssemblyUtil.createListQueryNode(jsonObjectList, OperateEnum.OPERATE_AND);
            }
            if(result == null){
                result = json;
            }else {
                if(OperateEnum.OPERATE_OR.getValue().equals(type)){
                    result = QueryConditionAssemblyUtil.addQueryNodeForSiblin(result, json, OperateEnum.OPERATE_OR);
                }else if(OperateEnum.OPERATE_AND_NOT.getValue().equals(type)){
                    result = QueryConditionAssemblyUtil.addQueryNodeForSiblin(result, json, OperateEnum.OPERATE_AND);
                }
            }
        }
        return ServiceResponse.success(result);
    }

    @Override
    public ServiceResponse<List<StoreDTO>> listStoreByStoreInfoId(Integer storeInfoId) {
        StoreSearchDBDTO searchDBDTO = new StoreSearchDBDTO();
        searchDBDTO.setStoreInfoId(storeInfoId);
        com.github.pagehelper.Page<StoreDTO> storeDTOS = this.storeService.listStore(searchDBDTO, 1, 10000);
        return ServiceResponse.success(storeDTOS.getResult());
    }

    @Override
    public ServiceResponse<List<StoreDTO>> listStore(String search, Integer enterpriseId) {
        StoreSearchDTO storeSearchDTO = new StoreSearchDTO();
        storeSearchDTO.setEnterpriseId(enterpriseId);
        storeSearchDTO.setSearch(search);
        ServiceResponse<Page<StoreDTO>> response = this.listStore(storeSearchDTO, 1, 10000);
        if(response.isSuccess() && response.getResult() != null){
            return ServiceResponse.success(response.getResult().getResult());
        }
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<Page<StoreDTO>> pageNearbyStore(Integer enterpriseId, String cityId, String longitude,
                                                           String latitude, Integer brandId, String appid,
                                                           Integer pageNum, Integer pageSize) {
        ServiceResponse<CustomStoreDTO> customStore = this.customStoreApiService.getCustomStore(enterpriseId, appid);
        if(customStore.isSuccess() && customStore.getResult() != null){
            Integer storeWidgetId = customStore.getResult().getStoreWidgetId();
            ServiceResponse<List<Integer>> response = this.storeWidgetApiService.listStoreIdByStoreWidgetId(enterpriseId, storeWidgetId);
            if(response.isSuccess() && CollectionUtils.isNotEmpty(response.getResult())){
                StoreSearchDBDTO searchDBDTO = new StoreSearchDBDTO();
                searchDBDTO.setEnterpriseId(enterpriseId);
                searchDBDTO.setStoreBrandId(brandId);
                searchDBDTO.setLongitude(longitude);
                searchDBDTO.setLatitude(latitude);
                searchDBDTO.setCityId(cityId);
                searchDBDTO.setStoreIdList(response.getResult());
                com.github.pagehelper.Page<StoreDTO> page = this.storeService.listStore(searchDBDTO, pageNum, pageSize);
                Page<StoreDTO> storeDTOPage = PageHelperUtils.changePageHelperToCurrentPage(page);
                logger.info("pageNearbyStore:{}", JSON.toJSONString(storeDTOPage, true));
                return ServiceResponse.success(storeDTOPage);
            }
        }
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<Void> storeQrcodeCallBack(String param) {
        return null;
    }

    @Override
    public ServiceResponse<StoreDTO> getStoreById(Integer enterpriseId, Integer storeId) {
        String key = Constants.STORE_KEY + enterpriseId + ":" + storeId;

        StoreDTO storeDTO = (StoreDTO) RedisUtil.getCache(key);
        if (storeDTO == null) {
            storeDTO = this.getStoreDTO(enterpriseId, storeId);
            if (storeDTO == null) {
                logger.info("enterpriseId:{}, storeId:{} , 门店不存在", enterpriseId, storeId);
                return ServiceResponse.failure(ErrorCode.NOTEXISTS.getCode(), ErrorCode.NOTEXISTS.getMsg());
            }
            // todo 修改门店缓存时间
            RedisUtil.setCache(key, storeDTO, storeExpiredTime, TimeUnit.HOURS);
        }
        return ServiceResponse.success(storeDTO);
    }

    private StoreDTO getStoreDTO(Integer enterpriseId, Integer storeId) {
        StoreDTO store = storeService.getById(storeId);
        if (store == null) {
            return null;
        }
        TabStoreRegion tabStoreRegion = this.storeRegionService.getById(enterpriseId, store.getRegionId());
        if (tabStoreRegion == null) {
            return null;
        }
        StoreDTO storeDTO = EntityUtil.changeEntityByOrika(StoreDTO.class, store);
        storeDTO.setRegionName(tabStoreRegion.getRegionName());
        TabStoreGroup storeGroup = storeGroupService.getStoreGroupById(storeDTO.getStoreGroupId());
        if (storeGroup != null) {
            storeDTO.setStoreGroupName(storeGroup.getStoreGroupName());
            String storeGroupChain = storeGroup.getStoreGroupChain();
            String[] storeIdArr = storeGroupChain.split("_");
            List<Integer> storeGroupIdList = new ArrayList<>();
            for (String s : storeIdArr) {
                if (StringUtils.isNotBlank(s)) {
                    storeGroupIdList.add(Integer.valueOf(s));
                }
            }
            storeDTO.setStoreGroupIdList(storeGroupIdList);
        }
        // 门店照片
        List<TabStorePhoto> tabPhotoList = storePhotoService.listStorePhoto(storeDTO.getEnterpriseId(), storeDTO.getStoreInfoId());
        List<StorePhotoDTO> photoDTOList = EntityUtil.changeEntityListByOrika(StorePhotoDTO.class, tabPhotoList);
        storeDTO.setPhotoList(photoDTOList);
        // 营业时间
        List<TabStoreBusinessTime> tabBusinessTimeList = storeBusinessTimeService.listBusinessTime(store.getStoreInfoId());
        if (CollectionUtils.isNotEmpty(tabBusinessTimeList)) {
            List<StoreBusinessTimeDTO> businessTimeDTOList = EntityUtil.changeEntityListByOrika(StoreBusinessTimeDTO.class, tabBusinessTimeList);
            storeDTO.setBusinessTimeList(businessTimeDTOList);
            storeBusinessTimeService.convertBusinessTime(businessTimeDTOList);
        }
        // 门店品牌
        List<TabStoreBrand> storeBrandList = storeBrandService.listStoreBrandByIds(store.getBrandIds());
        if (CollectionUtils.isNotEmpty(storeBrandList)) {
            List<StoreBrandDTO> brandDTOList = EntityUtil.changeEntityListByOrika(StoreBrandDTO.class, storeBrandList);
            storeDTO.setBrandList(brandDTOList);
            List<Integer> storeBrandIdList = new ArrayList<>();
            String storeBrandNames = "";
            for (StoreBrandDTO storeBrandDTO : brandDTOList) {
                storeBrandIdList.add(storeBrandDTO.getStoreBrandId());
                storeBrandNames += storeBrandDTO.getStoreBrandName() + ",";
            }
            storeDTO.setStoreBrandIdList(storeBrandIdList);
            storeDTO.setStoreBrandNames(StringUtils.isBlank(storeBrandNames) ? "" : storeBrandNames.substring(0, storeBrandNames.length() - 1));
        }

        // 自定义属性
        List<TabStoreExtend> extendList = storeExtendService.listByStoreInfoId(enterpriseId, storeDTO.getStoreInfoId());
        List<StoreExtendDTO> extendDTOList = storeExtendService.convertStoreExtendToDTO(extendList);
        storeDTO.setStoreExtendList(extendDTOList);
        Integer fromEnterpriseId = storeDTO.getFromEnterpriseId();
        if (fromEnterpriseId != null) {
            ServiceResponse<EnterpriseDTO> serviceResponse = enterpriseApiService.getEnterpriseById(fromEnterpriseId);
            if (serviceResponse.isSuccess()) {
                EnterpriseDTO enterpriseDTO = serviceResponse.getResult();
                storeDTO.setFromEnterpriseName(enterpriseDTO.getEnterpriseName());
            }
        }
        return storeDTO;
    }

    @Override
    public ServiceResponse<Void> validateFieldExceptRepeat(String value, StoreFieldDTO storeFieldDTO) {
        Integer storeFieldType = storeFieldDTO.getStoreFieldType();
        String storeFieldDetail = storeFieldDTO.getStoreFieldDetail();
        FieldBase fieldBase;
        if (StoreFieldTypeEnum.TEXT.getCode() == storeFieldType) {
            fieldBase = JSON.parseObject(storeFieldDetail, TextField.class);
        } else if (StoreFieldTypeEnum.RADIO.getCode() == storeFieldType) {
            fieldBase = JSON.parseObject(storeFieldDetail, RadioField.class);
        } else if (StoreFieldTypeEnum.CHECK.getCode() == storeFieldType) {
            fieldBase = JSON.parseObject(storeFieldDetail, CheckField.class);
        } else if (StoreFieldTypeEnum.REAL_NUMBER.getCode() == storeFieldType) {
            fieldBase = JSON.parseObject(storeFieldDetail, RealNumberField.class);
        } else if (StoreFieldTypeEnum.DATE.getCode() == storeFieldType) {
            fieldBase = JSON.parseObject(storeFieldDetail, DateTypeField.class);
        } else {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "不存在该自定义属性类型");
        }
        String msg;
        if (StoreFieldTypeEnum.RADIO.getCode() == storeFieldType || StoreFieldTypeEnum.CHECK.getCode() == storeFieldType) {
            List<TabStoreFieldSelect> fieldSelectList = storeFieldSelectService.listStoreFieldSelect(storeFieldDTO.getStoreFieldId(), null, 1, Integer.MAX_VALUE);
            List<String> nameList = fieldSelectList.stream().map(TabStoreFieldSelect::getStoreFieldSelectName).collect(Collectors.toList());
            msg = fieldBase.validateSelect(value, nameList);
        } else {
            msg = fieldBase.validate(value);
        }

        if (StringUtils.isBlank(msg)) {
            return ServiceResponse.success();
        } else {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), storeFieldDTO.getStoreFieldName() + "  " + msg);
        }
    }

    @Override
    public ServiceResponse<Page<StoreDTO>> listStoreOverFlow(Integer enterpriseId, Page<StoreDTO> page, String search) {
        StoreSearchDBDTO searchDBDTO = new StoreSearchDBDTO();
        searchDBDTO.setEnterpriseId(enterpriseId);
        searchDBDTO.setOverflowStatus(com.gic.enterprise.constants.Constants.NORMAL_STATUS);
        searchDBDTO.setSearch(search);
        com.github.pagehelper.Page<StoreDTO> storeDTOS = this.storeService.listStore(searchDBDTO, page.getCurrentPage(), page.getPageSize());
        page = PageHelperUtils.changePageHelperToCurrentPage(storeDTOS, StoreDTO.class);
        return ServiceResponse.success(page);
    }

    @Override
    public ServiceResponse bulkUpdateStore(String storeIds, String value, Integer enterpriseId, int type, Integer operatorId, String operatorName) {
        //type表示操作的类型，1更新门店启用状态，2门店电话，3营业时间，4门店照片（替换），5关联品牌，6批量上传图片（原有基础上新增）
        //7批量修改门店分组
        if (StringUtils.isBlank(storeIds) || StringUtils.isBlank(value)) {
            return EnterpriseServiceResponse.failure(com.gic.enterprise.error.ErrorCode.MISS_PARAMETER);
        }
        int i = 0;
        try {
            String storeInfoIds = storeService.listStoreInfoIdByStoreIds(storeIds, enterpriseId);
            if (StringUtils.isBlank(storeInfoIds)) {
                return ServiceResponse.success();
            }
            i = storeStrtegyMap.get(type).bulkUpdateStore(storeInfoIds, enterpriseId, value, storeService, operatorId, operatorName);
            List<Integer> storeIdList = new ArrayList<>();
            if ("all".equals(storeIds)) {
                this.removeCache(enterpriseId);
            } else {
                String[] storeIdArr = storeIds.split(",");
                for (String s : storeIdArr) {
                    storeIdList.add(Integer.valueOf(s));
                }
                this.removeCache(enterpriseId, storeIdList);
            }
            if (type == 1 || type == 5 || type == 7) {
                if ("all".equals(storeIds)) {
                    this.bulkUpdateStoreToIndex(enterpriseId);
                } else {
                    this.bulkUpdateStoreToIndex(enterpriseId, storeIdList);
                }
            }
        } catch (Exception e) {
            logger.error(e.getMessage());
        }

        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<StoreDTO> getByStoreNameAndStoreCode(Integer enterpriseId, String storeName, String storeCode) {
        StoreDTO store = this.storeService.getByStoreNameAndStoreCode(enterpriseId, storeName, storeCode);
        if (store != null) {
            return ServiceResponse.success(EntityUtil.changeEntityByOrika(StoreDTO.class, store));
        } else {
            return ServiceResponse.success();
        }
    }

    @Override
    public ServiceResponse addStoreToIndex(Integer enterpriseId, Integer storeId) {
        logger.info("addStoreToIndex:{},{}",enterpriseId,storeId);
        boolean isAdd = true;
        DynamicSearchDTO dynamicSearchDTO = new DynamicSearchDTO();
        JSONObject search = QueryConditionAssemblyUtil.createSimpleQueryNode("id", OperateEnum.OPERATE_EQ, enterpriseId + "_" + storeId);
        dynamicSearchDTO.setEnterpriseId(com.gic.enterprise.constants.Constants.INDEX_ENTERPRISEID);
        dynamicSearchDTO.setColumnCategoryCode(com.gic.enterprise.constants.Constants.ColumnCategoryCode);
        dynamicSearchDTO.setSearchJson(search);
        ServiceResponse<Long> serviceResponse = this.esBusinessOperaApiService.queryDataCount(dynamicSearchDTO);
        if (serviceResponse.isSuccess()) {
            Long result = serviceResponse.getResult();
            if (result != null) {
                if (result > 0) {
                    isAdd = false;
                }
            }
        }
        DynamicDocDTO docDTO = this.buildStoreDocDto(enterpriseId, storeId);
        logger.info("写入es的门店数据：{}", JSON.toJSONString(docDTO, true));
        if (docDTO != null) {
            ServiceResponse esResponse = null;
            if (isAdd) {
                esResponse = this.esBusinessOperaApiService.createDataSingle(docDTO, false);
            } else {
                esResponse = this.esBusinessOperaApiService.updateDataSingle(docDTO, false);
            }
            logger.info("门店写入es返回结果：{}", JSON.toJSONString(esResponse));
            if (esResponse.isSuccess()) {
                return esResponse;
            }
            return EnterpriseServiceResponse.failure(esResponse.getCode(), esResponse.getMessage());
        }
        return null;
    }

    @Override
    public ServiceResponse bulkAddStoreToIndex(Integer enterpriseId) {
        List<Integer> storeIdList = this.storeService.listAllStoreId(enterpriseId);
        return this.bulkAddStoreToIndex(enterpriseId, storeIdList);
    }

    @Override
    public ServiceResponse bulkAddStoreToIndex(Integer enterpriseId, List<Integer> storeIdList) {
        if (CollectionUtils.isNotEmpty(storeIdList)) {
            List<DynamicDocDTO> dynamicDocDTOList = new ArrayList<>();
            for (int i = 0; i < storeIdList.size(); i++) {
                DynamicDocDTO docDTO = this.buildStoreDocDto(enterpriseId, storeIdList.get(i));
                dynamicDocDTOList.add(docDTO);
                if (dynamicDocDTOList.size() == 200) {
                    this.esBusinessOperaApiService.createDataBatch(dynamicDocDTOList, true);
                    dynamicDocDTOList.clear();
                }
            }
            if (CollectionUtils.isNotEmpty(dynamicDocDTOList)) {
                this.esBusinessOperaApiService.createDataBatch(dynamicDocDTOList, true);
            }
        }
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse updateStoreToIndex(Integer enterpriseId, Integer storeId, Long indexId) {
        return null;
    }

    @Override
    public ServiceResponse bulkUpdateStoreToIndex(Integer enterpriseId) {
        List<Integer> storeIdList = this.storeService.listAllStoreId(enterpriseId);
        return this.bulkUpdateStoreToIndex(enterpriseId, storeIdList);
    }

    @Override
    public ServiceResponse bulkUpdateStoreToIndex(Integer enterpriseId, List<Integer> storeIdList) {
        if (CollectionUtils.isNotEmpty(storeIdList)) {
            List<DynamicDocDTO> dynamicDocDTOList = new ArrayList<>();
            for (int i = 0; i < storeIdList.size(); i++) {
                DynamicDocDTO docDTO = this.buildStoreDocDto(enterpriseId, storeIdList.get(i));
                dynamicDocDTOList.add(docDTO);
                if (dynamicDocDTOList.size() == 200) {
                    this.esBusinessOperaApiService.updateDataBatch(dynamicDocDTOList, true);
                    dynamicDocDTOList.clear();
                }
            }
            if (CollectionUtils.isNotEmpty(dynamicDocDTOList)) {
                this.esBusinessOperaApiService.updateDataBatch(dynamicDocDTOList, true);
            }
        }
        return ServiceResponse.success();
    }

    private DynamicDocDTO buildStoreDocDto(Integer enterpriseId, Integer storeId) {
        ServiceResponse<StoreDTO> response = this.getStoreById(enterpriseId, storeId);
        if (response.isSuccess()) {
            StoreDTO dto = response.getResult();
            StoreEsDTO esDTO = new StoreEsDTO();
            esDTO.setAreaIds(Arrays.asList(dto.getProvinceId(), dto.getCityId(), dto.getAreaId()));
            esDTO.setCityId(dto.getCityId());
            esDTO.setCompleteStatus(dto.getCompleteStatus());
            esDTO.setCountyId(dto.getAreaId());
            esDTO.setCreateType(dto.getCreateType());
            esDTO.setEnterpriseId(enterpriseId);
            esDTO.setErpStatus(dto.getErpStatus());
            esDTO.setId(enterpriseId + "_" + storeId);
            esDTO.setProvinceId(dto.getProvinceId());
            esDTO.setProvinces(dto.getProvinces());
            esDTO.setRegionId(dto.getRegionId());
            esDTO.setRegionName(dto.getRegionName());
            esDTO.setStatus(dto.getStatus());
            esDTO.setStoreBrandIdList(dto.getStoreBrandIdList());
            esDTO.setStoreBrands(dto.getStoreBrandNames());
            esDTO.setStoreCode(dto.getStoreCode());
            esDTO.setStoreGroupId(dto.getStoreGroupId());
            esDTO.setStoreGroupIdList(dto.getStoreGroupIdList());
            esDTO.setStoreId(dto.getStoreId());
            esDTO.setStoreInfoId(dto.getStoreInfoId());
            esDTO.setStoreGroupName(dto.getStoreGroupName());
            esDTO.setStoreName(dto.getStoreName());
            esDTO.setStoreType(dto.getStoreType());
            esDTO.setOwnType(dto.getOwnType());
            esDTO.setBusinessTimeList(dto.getBusinessTimeList());
            esDTO.setPhotoList(dto.getPhotoList());
            esDTO.setAddress(dto.getAddress());
            Double[] location = {Double.valueOf(dto.getLongitude()),Double.valueOf(dto.getLatitude())};
            JSONObject jsonObject = JSON.parseObject(JSON.toJSONString(esDTO));
            jsonObject.put("location", location);
            List<StoreExtendDTO> storeExtendDTOList = dto.getStoreExtendList();
            for (StoreExtendDTO extendDTO : storeExtendDTOList) {
                String key = "enterprise:store:storeField:" + enterpriseId + ":" + extendDTO.getStoreFieldId();
                Object existObj = RedisUtil.getCache(key);
                if (existObj != null && extendDTO.getStoreFieldType().intValue() != StoreFieldTypeEnum.TEXT.getCode()) {
                    if (extendDTO.getStoreFieldType().intValue() == StoreFieldTypeEnum.DATE.getCode()) {
                        String value = null;
                        if(StringUtils.isNotBlank(extendDTO.getValue())){
                            value = extendDTO.getValue().replaceAll("-", "").
                                    replaceAll(":", "").replaceAll(" ", "");
                        }
                        jsonObject.put(existObj.toString(), value == null ? 0l : Long.valueOf(value));
                    } else {
                        jsonObject.put(existObj.toString(), extendDTO.getValue() == null ? 0 : Long.valueOf(extendDTO.getValue()));
                    }
                }
            }
            DynamicDocDTO docDTO = new DynamicDocDTO();
            docDTO.setEnterpriseId(com.gic.enterprise.constants.Constants.INDEX_ENTERPRISEID);
            docDTO.setColumnCategoryCode(com.gic.enterprise.constants.Constants.ColumnCategoryCode);
            docDTO.setDocJson(jsonObject);
            return docDTO;
        }
        return null;
    }

    private void removeCache(Integer enterpriseId) {
        RedissonClient redisClient = RedisUtil.getRedisClient();
        RKeys keys = redisClient.getKeys();
        keys.deleteByPattern(Constants.STORE_KEY + enterpriseId + ":*");
    }

    private void removeCache(Integer enterpriseId, List<Integer> storeIds) {
        for (Integer storeId : storeIds) {
            String key = Constants.STORE_KEY + enterpriseId + ":" + storeId;
            RedisUtil.delCache(key);
        }
    }

    private JSONObject buildSearchJSON(StoreSearchDTO storeSearchDTO){
        List<JSONObject> jsonObjectList = new ArrayList<>();
        JSONObject enterpriseJson = QueryConditionAssemblyUtil.createSimpleQueryNode(StoreESFieldsEnum.ENTERPRISEID.getField(), OperateEnum.OPERATE_EQ, storeSearchDTO.getEnterpriseId());
        jsonObjectList.add(enterpriseJson);
        JSONObject json = null;
        if (storeSearchDTO.getStoreGroupId() != null) {
            json = QueryConditionAssemblyUtil.createSimpleQueryNode(StoreESFieldsEnum.STOREGROUPIDLIST.getField(), OperateEnum.OPERATE_ARR_CONTAIN, storeSearchDTO.getStoreGroupId());
            jsonObjectList.add(json);
        }
        if(storeSearchDTO.getRegionId() != null){
            json = QueryConditionAssemblyUtil.createSimpleQueryNode(StoreESFieldsEnum.REGIONID.getField(), OperateEnum.OPERATE_EQ, storeSearchDTO.getRegionId());
            jsonObjectList.add(json);
        }
        if (storeSearchDTO.getProvinceId() != null) {
            json = QueryConditionAssemblyUtil.createSimpleQueryNode(StoreESFieldsEnum.PROVINCEID.getField(), OperateEnum.OPERATE_EQ, storeSearchDTO.getProvinceId());
            jsonObjectList.add(json);
        }
        if (storeSearchDTO.getCityId() != null) {
            json = QueryConditionAssemblyUtil.createSimpleQueryNode(StoreESFieldsEnum.CITYID.getField(), OperateEnum.OPERATE_EQ, storeSearchDTO.getCityId());
            jsonObjectList.add(json);
        }
        if (storeSearchDTO.getCountyId() != null) {
            json = QueryConditionAssemblyUtil.createSimpleQueryNode(StoreESFieldsEnum.COUNTYID.getField(), OperateEnum.OPERATE_EQ, storeSearchDTO.getCountyId());
            jsonObjectList.add(json);
        }
        if (storeSearchDTO.getCreateType() != null) {
            json = QueryConditionAssemblyUtil.createSimpleQueryNode(StoreESFieldsEnum.CREATETYPE.getField(), OperateEnum.OPERATE_EQ, storeSearchDTO.getCreateType());
            jsonObjectList.add(json);
        }
        if (storeSearchDTO.getStatus() != null) {
            json = QueryConditionAssemblyUtil.createSimpleQueryNode(StoreESFieldsEnum.STATUS.getField(), OperateEnum.OPERATE_EQ, storeSearchDTO.getStatus());
            jsonObjectList.add(json);
        }
        if (StringUtils.isNotBlank(storeSearchDTO.getSearch())) {
            JSONObject storeNameSearch = QueryConditionAssemblyUtil.createSimpleQueryNode(StoreESFieldsEnum.STORENAME.getField(), OperateEnum.OPERATE_LIKE, storeSearchDTO.getSearch());
            JSONObject storeCodeSearch = QueryConditionAssemblyUtil.createSimpleQueryNode(StoreESFieldsEnum.STORECODE.getField(), OperateEnum.OPERATE_LIKE, storeSearchDTO.getSearch());
            JSONObject storeAreaSearch = QueryConditionAssemblyUtil.createSimpleQueryNode(StoreESFieldsEnum.PROVINCES.getField(), OperateEnum.OPERATE_LIKE, storeSearchDTO.getSearch());
            List<JSONObject> list = new ArrayList<>();
            list.add(storeAreaSearch);
            list.add(storeCodeSearch);
            list.add(storeNameSearch);
            json = QueryConditionAssemblyUtil.createListQueryNode(list, OperateEnum.OPERATE_OR);
            jsonObjectList.add(json);
        }
        if (StringUtils.isNotBlank(storeSearchDTO.getStoreIds())) {
            json = QueryConditionAssemblyUtil.createSimpleQueryNode(StoreESFieldsEnum.STOREID.getField(), OperateEnum.OPERATE_ARR_CONTAIN, storeSearchDTO.getStoreIds());
            jsonObjectList.add(json);
        }
        if(StringUtils.isNotBlank(storeSearchDTO.getStoreInfoIds())){
            json = QueryConditionAssemblyUtil.createSimpleQueryNode(StoreESFieldsEnum.STOREINFOID.getField(), OperateEnum.OPERATE_ARR_CONTAIN, storeSearchDTO.getStoreInfoIds());
            jsonObjectList.add(json);
        }
        if(storeSearchDTO.getStoreBrandId() != null){
            json = QueryConditionAssemblyUtil.createSimpleQueryNode(StoreESFieldsEnum.STOREBRANDIDLIST.getField(), OperateEnum.OPERATE_ARR_CONTAIN, storeSearchDTO.getStoreBrandId());
            jsonObjectList.add(json);
        }
        if(StringUtils.isNotBlank(storeSearchDTO.getSearchJson())){
            ServiceResponse<JSONObject> jsonObjectServiceResponse = this.parseStoreSelectJson(storeSearchDTO.getSearchJson());
            if(jsonObjectServiceResponse.isSuccess()){
                json = jsonObjectServiceResponse.getResult();
                jsonObjectList.add(json);
            }
        }
        if(StringUtils.isNotBlank(storeSearchDTO.getAuthSearchJson())){
            ServiceResponse<JSONObject> jsonObjectServiceResponse = this.parseStoreSelectJson(storeSearchDTO.getAuthSearchJson());
            if(jsonObjectServiceResponse.isSuccess()){
                json = jsonObjectServiceResponse.getResult();
                jsonObjectList.add(json);
            }
        }
        if(StringUtils.isNotBlank(storeSearchDTO.getLatitude()) && StringUtils.isNotBlank(storeSearchDTO.getLongitude())){
            json = QueryConditionAssemblyUtil.createSimpleQueryNode(StoreESFieldsEnum.LOCATION.getField(), OperateEnum.OPERATE_LOCATION, storeSearchDTO.getLatitude()+","+storeSearchDTO.getLongitude());
            jsonObjectList.add(json);
        }
        enterpriseJson = QueryConditionAssemblyUtil.createListQueryNode(jsonObjectList, OperateEnum.OPERATE_AND);
        return enterpriseJson;
    }
}
